pub enum PackageRef {
ByName(PackageName),
ById(PackageId),
}Expand description
A package reference provided by callers or CLI commands.
Package references can either name a package directly or point to an
explicit catalog id via @winget/<id>, @scoop/<bucket>/<id>,
@chocolatey/<id>, or @winbrew/<id> syntax.
Variants
ByName(PackageName)
Reference by display name or package name.
ById(PackageId)
Reference by explicit package id.
Implementations
Sourceimpl PackageRef
impl PackageRef
Sourcepub fn parse(input: &str) -> Result<Self, ModelError>
pub fn parse(input: &str) -> Result<Self, ModelError>
Parse a package reference from name or an explicit catalog id.